@@ -54,7 +54,7 @@
 #include "modules.h"
 
 static char const rcsid[] =
-    "$Id: net.c,v 1.64 2003/07/11 10:30:54 jordim Exp $";
+    "$Id: net.c,v 1.67 2003/12/19 12:43:59 lobbin Exp $";
 
 
 /* Local functions */
@@ -82,10 +82,11 @@ gchar *host = "", *port = "";
 static void check_aliases(GString *string, CONNECTION_DATA *cd, gchar *t, gint level)
 {
 	gchar **a = g_strsplit (t," ", -1), *r;
+	gboolean checked = FALSE;
 
-	if (level > 5)
+	if (level > 0)
 	{
-		g_message("Maximum nested alias reached.");
+		//g_message("Maximum nested alias reached.");
 		append_word_to_command (string, t);
 		return;
 	}
@@ -94,9 +95,18 @@ static void check_aliases(GString *string, CONNECTION_DATA *cd, gchar *t, gint l
 	{
 		gchar *b = *a++;
 		
-		if ((r = check_alias (cd->profile->alias, b)))
+		if (!checked)
 		{
-			check_aliases(string, cd, r, level+1);
+			if ((r = check_alias (cd->profile->alias, b)))
+			{
+				check_aliases(string, cd, r, level+1);
+			}
+			else
+			{
+				append_word_to_command (string, b);
+			}
+
+			checked = TRUE;
 		}
 		else
 		{
@@ -115,9 +125,10 @@ void action_send_to_connection (gchar *entry_text, CONNECTION_DATA *connection)
 
 	a = g_strdup(alias->str);
 	g_string_free(alias, TRUE);
+	strcat(a,"\n"); // This way we avoid calling trigeer parsing functions twice (once with an empty parameter)
 	
-   	connection_send (connection, check_vars (connection->profile->variables, a));
-	connection_send (connection, "\n");
+	connection_send (connection, check_vars (connection->profile->variables, a));
+//	connection_send (connection, "\n");
 
 #ifndef WITHOUT_MAPPER	
 	for (puck = AutoMapList; puck!= NULL; puck = puck->next)
@@ -216,6 +227,7 @@ void open_connection (CONNECTION_DATA *connection)
     textfield_add (connection, buf, MESSAGE_SYSTEM);
 
     /* strerror(3) */
+    memset(&req,0,sizeof(req));
     req.ai_flags = 0;
     req.ai_family = AF_UNSPEC;
     req.ai_socktype = SOCK_STREAM;
@@ -380,11 +392,24 @@ static void read_from_connection (CONNECTION_DATA *connection, gint source, GdkI
 
 void connection_send_data (CONNECTION_DATA *connection, gchar *message, int echo, gboolean secret)
 {
-    gint i;
-    gchar *sent;
+	gint i;
+	gchar *sent;
+	GList *t;
   
-    if (connection->connected)
-    {
+	for (t = g_list_first(Plugin_data_list); t != NULL; t = t->next) {
+		PLUGIN_DATA *pd;
+     
+		if (t->data != NULL)
+		{
+			pd = (PLUGIN_DATA *) t->data;
+			if (pd->plugin && pd->plugin->enabeled && (pd->dir == PLUGIN_DATA_OUT)) {
+				(* pd->datafunc) (pd->plugin, connection, message, GPOINTER_TO_INT(pd->plugin->handle));
+	    		}
+		}
+	}
+    
+	if (connection->connected)
+	{
 		sent = g_strdup (message);
 
 #ifdef USE_PYTHON
